@@ -18,7 +18,7 @@
 #
 #    (C) 2005 Nicolas Évrard <nicoe@nutellux.be>
 
-__revision__ = "$Id: gnomolicious.py,v 1.18 2006/01/13 15:04:53 nicoe Exp $"
+__revision__ = "$Id: gnomolicious.py,v 1.20 2006/02/28 22:15:27 nicoe Exp $"
 
 import os.path
 import re
@@ -158,8 +158,6 @@ class GnomoliciousApplet(gnomeapplet.Applet):
                                                               'gnomolicious.png'
                                                               ))
         self.on_resize_panel(self, self.applet.get_size())
-        self.applet.add(self.visual)
-        self.applet.show_all()
 
         # connecting signals
         logger.debug('Connecting the signals')
@@ -322,16 +320,25 @@ class GnomoliciousApplet(gnomeapplet.Applet):
             entry_tags.append(tag)
             self.postwin.entries['tags'].set_text(' '.join(entry_tags))
 
-    def on_resize_panel(self, widget, data):
-        logger.debug('New size: %s' % data)
+    def on_resize_panel(self, widget, size):
+        logger.debug('New size: %s' % size)
         pixbuf = self.logo
-        new_pixbuf = pixbuf.scale_simple(data-1, data-1,
+        new_pixbuf = pixbuf.scale_simple(size-1, size-1,
                                          gtk.gdk.INTERP_BILINEAR)
         self.visual = gtk.Image()
         self.visual.set_from_pixbuf(new_pixbuf)
+        self.applet.add(self.visual)
+        self.applet.show_all()
 
-    def on_bckg_change(self, widget, background, foo, pixmap):
-        logger.debug('New background: %s %s' % (widget, args))
+    def on_bckg_change(self, widget, background, colour, pixmap):
+        logger.debug('New background: %s,%s,%s' % (background, colour, pixmap))
+        if background == gnomeapplet.NO_BACKGROUND:
+            #widget.modify_style(gtk.RcStyle())
+            pass
+        elif background == gnomeapplet.COLOR_BACKGROUND:
+            widget.modify_bg(gtk.STATE_NORMAL, colour)
+        elif background == gnomeapplet.PIXMAP_BACKGROUND:
+            pass
 
     def on_dragdata_received(self, widget, context, x, y, selection, ttype,
                              time):
@@ -345,8 +352,11 @@ class GnomoliciousApplet(gnomeapplet.Applet):
         else:
             charset = 'utf-8'
         if title_match:
-            title = unicode(' '.join(title_match.groupdict()['title'].split()),
-                            charset)
+            try:
+                title = unicode(' '.join(title_match.groupdict()['title'].split()),
+                                charset)
+            except UnicodeDecodeError:
+                title = ' '.join(title_match.groupdict()['title'].split())
         else:
             title = ''
         self.postwin.entries['url'].set_text(url)
