@@ -398,7 +398,7 @@ class build_conf(Command):
         self.announce('Building conf.py file')
         fc = file(os.path.join('src', 'conf.py.in')).read()
         fw = file(os.path.join('src', 'conf.py'), 'w')
-        fw.write(fc % (self.prefix, self.prefix))
+        fw.write(fc % (self.prefix, self.prefix, self.prefix))
         fw.close()
 
 class build_server(Command):
@@ -411,14 +411,17 @@ class build_server(Command):
         self.build_base = None
         self.install_dir = None
         self.install_pixmaps = None
+        self.intl_merge = commands.getoutput('which intltool-merge')
 
     def finalize_options(self):
+        if not os.path.exists(self.intl_merge):
+            sys.exit('intltool-merge does not exist in your PATH. ' + \
+                     'Make sure it exists in your PATH..')
         self.set_undefined_options('build',
                                     ('build_base', 'build_base'))
         self.set_undefined_options('install',
                                     ('install_scripts', 'install_dir'),
                                     ('prefix', 'install_pixmaps'))
-        
 
     def run(self):
         self.announce("Building server file")
@@ -426,10 +429,17 @@ class build_server(Command):
                             'servers'))
         self.mkpath(dest, 1)
         fc = file('data/gnomolicious.server.in').read()
-        fw = file(os.path.join(dest, 'gnomolicious.server'), 'w')
+        fw = file('data/gnomolicious.server', 'w')
         fw.write(fc % (self.install_dir, self.install_pixmaps))
         fw.close()
 
+        cmd = '%s -b -u po data/gnomolicious.server %s/gnomolicious.server' % (self.intl_merge, dest)
+        err, val = commands.getstatusoutput(cmd)
+        if err:
+            sys.exit('Error merging translation in gnomolicious.server')
+        print "%s" % val
+
+
 class install_server(install_data):
 
     description = 'Installs bonobo server file'
@@ -563,10 +573,11 @@ class translate(Command):
             sys.exit('po/ directory not found.. not continuing...')
 
         if self.pot:
-            cmd = '%s --pot' % self.intl_update
+            cmd = '%s --pot -g gnomolicious' % self.intl_update
             err, val = commands.getstatusoutput(cmd)
             if err:
                 sys.exit('Error generating template file %s' % self.pot_file)
+            self.announce('%s done' % val)
             print "%s" % val
 
         if self.dist:
